@@ -181,7 +181,7 @@ class Shap:
         shap_df = pd.DataFrame(data=shap_values, columns=self.models_dict_item["train_features"])
         if self.conf.analysis.shap_include_sorted_values or self.conf.analysis.shap_narrative_activate:
             logging.info("Obtaining the important features and the corresponding shap values for each data point...")
-            shap_df = parrallelize_dataframe(shap_df, self.handle_feature_importance)
+            shap_df = parrallelize_dataframe(shap_df, self.handle_feature_importance, self.conf.analysis.shap_num_cores)
             # this is the serial code
             # shap_df = self.handle_feature_importance(shap_df)
 
@@ -191,7 +191,7 @@ class Shap:
             logging.info("Creating narratives for each data point...")
             self.class_name = class_name
 
-            shap_df, test_data = parrallelize_dataframes(shap_df, test_data, self.handle_narrative)
+            shap_df, test_data = parrallelize_dataframes(shap_df, test_data, self.handle_narrative, self.conf.analysis.shap_num_cores)
             # this is the serial code
             # self.create_narrative(shap_df, test_data[self.models_dict_item["train_features"]], class_name=class_name if class_name is not None else "target")
         self.write_shap(tag, shap_df, test_data[self.conf.column.id_cols], class_name="_{c}".format(c=class_name) if class_name is not None else '')
